Crate ya_compile_time_utils

Crate ya_compile_time_utils 

Macros

git_tag
Returns latest version tag
git_version
Get the git version for the source code.
semver_str
Returns a semantic version string of the crate
version_describe

Functions

build_date
Returns current date in YYYY-MM-DD format.
build_number
Returns Github Actions build number if available or None.
build_number_str
Returns Github Actions build string if available or None.
git_rev
Returns latest commit short hash.
report_version_to_metrics
tag2semver
Converts a tag to semantic version